import './Checkers.css'
import React from 'react'

export const Color = {
    white: "WHITE",
    black: "BLACK",

    opposite: (color) => {
        if (color === Color.white)
            return Color.black;
        if (color === Color.black)
            return Color.white;

        return color;
    }
};

/*
 * Stone
 */
export function Stone({ color, type }) {
    switch (color) {
        case Color.white:
            return <WhiteStone type={type} />;

        case Color.black:
            return <BlackStone type={type} />;

        case '':
        case undefined:
        case null:
            return; // no stone :)

        default:
            console.warn("Unknown color: ", color)
    }
}

export function WhiteStone({ type }) {
    if (type === 'KING')
        return <span className="Stone white king">⛁</span>
    else
        return <span className="Stone white man">⛀</span>
}

export function BlackStone({ type }) {
    if (type === 'KING')
        return <span className="Stone white king">⛃</span>
    else
        return <span className="Stone black man">⛂</span>
}

/*
 * Player
 */
export function Player({ color, name }) {
    return (
        <div className='Player'>
            {name}
            <Stone color={color} />
        </div>
    )
}

/*
 * Board
 */
export function Board({ game }) {

    const board = (game && game.board && typeof game.board === 'object') ? game.board : defaultBoard();

    return <div className='Board'>
        <div className='row'>
            <BlackTile /> <WhiteTile id={1} stone={board[1]} />
            <BlackTile /> <WhiteTile id={2} stone={board[2]} />
            <BlackTile /> <WhiteTile id={3} stone={board[3]} />
            <BlackTile /> <WhiteTile id={4} stone={board[4]} />
        </div>
        <div className='row'>
            <WhiteTile id={5} stone={board[5]} /> <BlackTile />
            <WhiteTile id={6} stone={board[6]} /> <BlackTile />
            <WhiteTile id={7} stone={board[7]} /> <BlackTile />
            <WhiteTile id={8} stone={board[8]} /> <BlackTile />
        </div>
        <div className='row'>
            <BlackTile /> <WhiteTile id={9} stone={board[9]} />
            <BlackTile /> <WhiteTile id={10} stone={board[10]} />
            <BlackTile /> <WhiteTile id={11} stone={board[11]} />
            <BlackTile /> <WhiteTile id={12} stone={board[12]} />
        </div>
        <div className='row'>
            <WhiteTile id={13} stone={board[13]} /> <BlackTile />
            <WhiteTile id={14} stone={board[14]} /> <BlackTile />
            <WhiteTile id={15} stone={board[15]} /> <BlackTile />
            <WhiteTile id={16} stone={board[16]} /> <BlackTile />
        </div>

        <div className='row'>
            <BlackTile /> <WhiteTile id={17} stone={board[17]} />
            <BlackTile /> <WhiteTile id={18} stone={board[18]} />
            <BlackTile /> <WhiteTile id={19} stone={board[19]} />
            <BlackTile /> <WhiteTile id={20} stone={board[20]} />
        </div>
        <div className='row'>
            <WhiteTile id={21} stone={board[21]} /> <BlackTile />
            <WhiteTile id={22} stone={board[22]} /> <BlackTile />
            <WhiteTile id={23} stone={board[23]} /> <BlackTile />
            <WhiteTile id={24} stone={board[24]} /> <BlackTile />
        </div>
        <div className='row'>
            <BlackTile /> <WhiteTile id={25} stone={board[25]} />
            <BlackTile /> <WhiteTile id={26} stone={board[26]} />
            <BlackTile /> <WhiteTile id={27} stone={board[27]} />
            <BlackTile /> <WhiteTile id={28} stone={board[28]} />
        </div>
        <div className='row'>
            <WhiteTile id={29} stone={board[29]} /> <BlackTile />
            <WhiteTile id={30} stone={board[30]} /> <BlackTile />
            <WhiteTile id={31} stone={board[31]} /> <BlackTile />
            <WhiteTile id={32} stone={board[32]} /> <BlackTile />
        </div>
    </div>
}

function defaultBoard() {
    return {
        1: { color: "BLACK", type: "MAN" },
        2: { color: "BLACK", type: "MAN" },
        3: { color: "BLACK", type: "MAN" },
        4: { color: "BLACK", type: "MAN" },
        5: { color: "BLACK", type: "MAN" },
        6: { color: "BLACK", type: "MAN" },
        7: { color: "BLACK", type: "MAN" },
        8: { color: "BLACK", type: "MAN" },
        9: { color: "BLACK", type: "MAN" },
        10: { color: "BLACK", type: "MAN" },
        11: { color: "BLACK", type: "MAN" },
        12: { color: "BLACK", type: "MAN" },
        21: { color: "WHITE", type: "MAN" },
        22: { color: "WHITE", type: "MAN" },
        23: { color: "WHITE", type: "MAN" },
        24: { color: "WHITE", type: "MAN" },
        25: { color: "WHITE", type: "MAN" },
        26: { color: "WHITE", type: "MAN" },
        27: { color: "WHITE", type: "MAN" },
        28: { color: "WHITE", type: "MAN" },
        29: { color: "WHITE", type: "MAN" },
        30: { color: "WHITE", type: "MAN" },
        31: { color: "WHITE", type: "MAN" },
        32: { color: "WHITE", type: "MAN" },
    }
}

function WhiteTile({ id, stone }) {
    return (
        <div className='Tile white'
            onClick={() => console.log('click', id)}
        >
            <Stone color={stone?.color} type={stone?.type} />
        </div>
    );
}

function BlackTile() {
    return <div className='Tile black' />
}