import React, { useContext } from 'react';
import { useLocation, matchPath } from 'react-router-dom';
import { GamesContext } from '../../context/games';

import { Color, Player, Board } from '../../components/Checkers';
import './GameBoard.css';

export default function GameBoard() {
  const games = useContext(GamesContext);
  const { pathname } = useLocation();

  const game = (() => {
    if (matchPath('/games/new', pathname))
      return gameFrom(games.newGame);

    if (matchPath('/games/proposal', pathname))
      return games.findGame({ uuid: games.proposal.selectedUUID });
    else if (matchPath('/games/active', pathname))
      return games.findGame({ uuid: games.active.selectedUUID });
    else if (matchPath('/games/archive', pathname))
      return games.findGame({ uuid: games.archive.selectedUUID });

    return {}; //  defaults
  })(); // <<-- Execute

  const opponentColor = Color.opposite(game?.myColor);
console.log("game", game)
  return (
    <div className='GameBoard'>
      <Player color={opponentColor || Color.white} name={game?.opponentName} />
      <Board game={game} />
      <Player color={game?.myColor || Color.black} name={game?.opponentName ? 'MyName' : ''} />
    </div>
  )
}

function gameFrom(newGame) {
  return {
    myColor: Color.opposite(newGame.opponentColor),
    opponentName: newGame.opponentName,
    opponentColor: newGame.opponentColor,
    board: newGame.board,
  };
}